@@ -18,4 +18,14 @@ class Source(source.Source):
         return source.SourcePrice(price, time, 'CHF')
 
     def get_historical_price(self, ticker, time):
-        return None
+        us_timezone = tz.gettz("Europe/Zurich")
+        reqdate = time.astimezone(us_timezone).date()
+
+        resp = requests.get(url='https://api.exchangeratesapi.io/' + str(reqdate) + '?base=' + ticker + '&symbols=CHF')
+        data = resp.json()
+
+        price = D(str(data['rates']['CHF']))
+        date = parse(data['date'])
+
+        time = date.astimezone(us_timezone)
+        return source.SourcePrice(price, time, 'CHF')
